@@ -4,7 +4,6 @@ from datomizer import DatoTrainer
 from datomizer.helpers.common_helper import get_flow, wait_for_step_type, get_generated_zip, get_generated_csv
 from datomizer.helpers.generator.generator_helper import generate
 from datomizer.helpers.datasource.datasource_helper import create_target_private_datasource
-from datomizer.helpers.wrapper.schema_wrapper import NAME
 from datomizer.utils.general import TARGET_DATASOURCE_ID, ERROR
 from datomizer.utils.step_types import GENERATE
 
@@ -81,7 +80,7 @@ class DatoGenerator(object):
                     StringIO object containing the generated data"""
         self.restore_validation()
 
-        table_name = self.dato_trainer.dato_mapper.schema.table(table_name)[NAME]
+        table_name = self.dato_trainer.dato_mapper.schema.table(table_name).name
 
         return get_generated_csv(datomizer=self.dato_trainer.dato_mapper.datomizer,
                                  business_unit_id=self.dato_trainer.dato_mapper.business_unit_id,
