@@ -1,7 +1,8 @@
+import tempfile
+from pathlib import Path
 from datomizer import Datomizer
-from datomizer.helpers.datasource.datasource_helper import (create_origin_private_datasource_from_path,
-                                                            create_origin_private_datasource_from_df)
-from datomizer.helpers.common_helper import get_flow, wait_for_step_type
+from datomizer.helpers.datasource.datasource_helper import create_origin_private_datasource_from_path
+from datomizer.helpers.common_helper import get_flow, wait_for_step_type, save_df_to_csv, validate_data_size_limits
 from datomizer.helpers.business_unit_project.business_unit_project_helper import get_default_business_unit_project
 from datomizer.helpers.autodiscovery.autodiscovery_helper import discover, get_schema_discovery
 from datomizer.helpers.wrapper.schema_wrapper import SchemaWrapper
@@ -40,18 +41,15 @@ class DatoMapper(object):
         self.set_datasource_validation()
         self.datasource_id = create_origin_private_datasource_from_path(self.datomizer, path)
 
-    def create_datasource_from_df(self, df, name="temp_df") -> None:
-        self.set_datasource_validation()
-        self.datasource_id = create_origin_private_datasource_from_df(self.datomizer, df, name)
-
-    def create_datasource(self, path, df, name):
-        if path is not None:
-            self.create_datasource_from_path(path)
-        elif df is not None:
-            self.create_datasource_from_df(df, name)
+    def create_datasource(self, path, df, name, delimiter):
+        with tempfile.TemporaryDirectory() as temp_dir:
+            if df is not None:
+                path = save_df_to_csv(df, temp_dir, name)
+            validate_data_size_limits(path, delimiter)
+            self.create_datasource_from_path(Path(path))
 
     def discover(self, path=None, df=None, df_name=None, sample_percent: int = 1, title: str = "sdk_flow",
-                 wait=True) -> None:
+                 wait=True, delimiter: str = ',') -> None:
         """Extract the structure of the input data.
         Args:
             path: full path for the input data
@@ -59,8 +57,9 @@ class DatoMapper(object):
             df_name: the name of the input data
             sample_percent: the sampling ratio; 1 (100%) by default.
             title: the name of the created task in Datomize; "sdk_flow" by default.
-            wait: use wait=False for asynchronous programming; True by default (awaits for the results)."""
-        self.create_datasource(path, df, df_name if df_name else "temp_sdk")
+            wait: use wait=False for asynchronous programming; True by default (awaits for the results).
+            delimiter: default "," used for number of columns validation"""
+        self.create_datasource(path, df, df_name if df_name else "temp_sdk", delimiter)
 
         self.pre_run_validation()
         self.flow_id = discover(self.datomizer,
@@ -94,25 +93,20 @@ class DatoMapper(object):
         return self.schema
 
     def base_validation(self):
-        if not (self.business_unit_id > 0 and self.project_id > 0):
-            raise Exception("missing base properties")
+        assert (self.business_unit_id > 0 and self.project_id > 0), "missing base properties"
 
     def set_datasource_validation(self):
         self.base_validation()
-        if self.datasource_id > 0:
-            raise Exception("datasource id cannot be mutated")
+        assert self.datasource_id == 0, "datasource id cannot be mutated"
 
     def pre_run_validation(self):
         self.base_validation()
-        if not (self.datasource_id > 0):
-            raise Exception("datasource id required for this step")
+        assert self.datasource_id > 0, "datasource id required for this step"
 
     def restore_validation(self):
         self.base_validation()
-        if not (self.flow_id > 0):
-            raise Exception("flow id required for this step")
+        assert self.flow_id > 0, "flow id required for this step"
 
     def next_step_validation(self):
         self.restore_validation()
-        if not self.schema:
-            raise Exception("DatoMapper not ready")
+        assert self.schema, "DatoMapper not ready"
