@@ -1,8 +1,11 @@
 import json
+import base64
 import requests
 from datomizer import Datomizer
-from datomizer.utils.constants import MANAGEMENT_POST_ADD_FLOW, MANAGEMENT_GET_SCHEMA_DISCOVERY
+from datomizer.utils.constants import (MANAGEMENT_POST_ADD_FLOW, MANAGEMENT_GET_SCHEMA_DISCOVERY,
+                                       MANAGEMENT_GET_SCHEMA_DISCOVERY_PROTO)
 from datomizer.utils.general import ID
+from datomizer.protos.autodiscoveryservice_pb2 import SchemaDiscoveryDTO
 
 
 def create_flow_creation_request(datasource_id: int, sample_percent: int = 1, title: str = "new_flow") -> dict:
@@ -29,8 +32,8 @@ def discover(datomizer: Datomizer,
 
 
 def get_schema_discovery(datomizer: Datomizer,
-                         business_unit_id: str, project_id: str, flow_id: str) -> dict:
-    response_json = datomizer.get_response_json(requests.get,
-                                                url=MANAGEMENT_GET_SCHEMA_DISCOVERY,
-                                                url_params=[business_unit_id, project_id, flow_id])
-    return response_json
+                         business_unit_id: str, project_id: str, flow_id: str) -> SchemaDiscoveryDTO:
+    response_proto = datomizer.api_request(requests.get, headers={"Content-Type": "application/x-protobuf"},
+                                           url=MANAGEMENT_GET_SCHEMA_DISCOVERY_PROTO,
+                                           url_params=[business_unit_id, project_id, flow_id])
+    return SchemaDiscoveryDTO().FromString(response_proto.content)
