@@ -1,7 +1,8 @@
 import json
 import requests
 from datomizer import DatoMapper
-from datomizer.utils.constants import MANAGEMENT_PUT_TRAIN_FLOW
+from datomizer.helpers.wrapper.evaluation_wrapper import EvaluationWrapper
+from datomizer.utils.constants import MANAGEMENT_PUT_TRAIN_FLOW, MANAGEMENT_GET_MODEL_EVALUATION
 from datomizer.utils.general import ID, TRAIN_ITERATIONS
 
 
@@ -21,6 +22,16 @@ def train(dato_mapper: DatoMapper) -> int:
     return response_json
 
 
+def get_evaluation(dato_mapper: DatoMapper, model_id: int = 0) -> str:
+    response_json = dato_mapper.datomizer.get_response_json(requests.get,
+                                                            url=MANAGEMENT_GET_MODEL_EVALUATION,
+                                                            url_params=[dato_mapper.business_unit_id,
+                                                                        dato_mapper.project_id,
+                                                                        dato_mapper.flow_id,
+                                                                        model_id])
+    return EvaluationWrapper(response_json)
+
+
 def get_train_iteration(dato_mapper: DatoMapper, train_id) -> dict:
     flow = dato_mapper.get_flow()
     iteration = [t for t in flow[TRAIN_ITERATIONS] if t[ID] == train_id][0]
