@@ -31,3 +31,8 @@ class Metrics(enum.Enum):
     RECALL = "RECALL"
     RMSE = "RMSE"
     ROC_AUC = "ROC_AUC"
+    PR_AUC = "PR_AUC"
+
+
+def map_enum_list(enum_list: []):
+    return [obj.value for obj in enum_list]
